==> youtrack_rest_client-0.1.1-py3-none-any.whl: youtrack_rest_client/models/database_multi_value_issue_custom_field.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.database_multi_value_issue_custom_field_value import DatabaseMultiValueIssueCustomFieldValue
    from ..models.project_custom_field import ProjectCustomField
else:
    ProjectCustomField = "ProjectCustomField"
    DatabaseMultiValueIssueCustomFieldValue = "DatabaseMultiValueIssueCustomFieldValue"

from ..models.issue_custom_field import IssueCustomField

T = TypeVar("T", bound="DatabaseMultiValueIssueCustomField")


@attr.s(auto_attribs=True)
class DatabaseMultiValueIssueCustomField(IssueCustomField):
    """Represents the all custom fields that may have multiple values in the issue."""

    project_custom_field: Union[Unset, ProjectCustomField] = UNSET
    value: Union[Unset, DatabaseMultiValueIssueCustomFieldValue] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project_custom_field: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.project_custom_field, Unset):
            project_custom_field = self.project_custom_field.to_dict()

        value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.value, Unset):
            value = self.value.to_dict()

        field_dict: Dict[str, Any] = {}
        _IssueCustomField_dict = super().to_dict()
        field_dict.update(_IssueCustomField_dict)
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if project_custom_field is not UNSET:
            field_dict["projectCustomField"] = project_custom_field
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        _IssueCustomField_kwargs = super().from_dict(src_dict=d).to_dict()

        _project_custom_field = d.pop("projectCustomField", UNSET)
        project_custom_field: Union[Unset, ProjectCustomField]
        if isinstance(_project_custom_field, Unset):
            project_custom_field = UNSET
        else:
            project_custom_field = ProjectCustomField.from_dict(_project_custom_field)

        _value = d.pop("value", UNSET)
        value: Union[Unset, DatabaseMultiValueIssueCustomFieldValue]
        if isinstance(_value, Unset):
            value = UNSET
        else:
            value = DatabaseMultiValueIssueCustomFieldValue.from_dict(_value)

        database_multi_value_issue_custom_field = cls(
            project_custom_field=project_custom_field,
            value=value,
            **_IssueCustomField_kwargs,
        )

        database_multi_value_issue_custom_field.additional_properties = d
        return database_multi_value_issue_custom_field

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> youtrack_rest_client-0.1.2-py3-none-any.whl: youtrack_rest_client/models/database_multi_value_issue_custom_field.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="DatabaseMultiValueIssueCustomField")


try:
    from ..models import issue_custom_field
except ImportError:
    import sys

    issue_custom_field = sys.modules[__package__ + "issue_custom_field"]


@attr.s(auto_attribs=True)
class DatabaseMultiValueIssueCustomField(issue_custom_field.IssueCustomField):
    """Represents the all custom fields that may have multiple values in the issue."""

    project_custom_field: "Union[Unset, project_custom_field_m.ProjectCustomField]" = UNSET
    value: "Union[Unset, database_multi_value_issue_custom_field_value_m.DatabaseMultiValueIssueCustomFieldValue]" = (
        UNSET
    )
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project_custom_field: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.project_custom_field, Unset):
            project_custom_field = self.project_custom_field.to_dict()

        value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.value, Unset):
            value = self.value.to_dict()

        field_dict: Dict[str, Any] = {}
        _IssueCustomField_dict = super().to_dict()
        field_dict.update(_IssueCustomField_dict)
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if project_custom_field is not UNSET:
            field_dict["projectCustomField"] = project_custom_field
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:

        try:
            from ..models import (
                database_multi_value_issue_custom_field_value as database_multi_value_issue_custom_field_value_m,
            )
            from ..models import project_custom_field as project_custom_field_m
        except ImportError:
            import sys

            database_multi_value_issue_custom_field_value_m = sys.modules[
                __package__ + "database_multi_value_issue_custom_field_value"
            ]
            project_custom_field_m = sys.modules[__package__ + "project_custom_field"]

        d = src_dict.copy()

        _IssueCustomField_kwargs = super().from_dict(src_dict=d).to_dict()

        _project_custom_field = d.pop("projectCustomField", UNSET)
        project_custom_field: Union[Unset, project_custom_field_m.ProjectCustomField]
        if isinstance(_project_custom_field, Unset):
            project_custom_field = UNSET
        else:
            project_custom_field = project_custom_field_m.ProjectCustomField.from_dict(_project_custom_field)

        _value = d.pop("value", UNSET)
        value: Union[Unset, database_multi_value_issue_custom_field_value_m.DatabaseMultiValueIssueCustomFieldValue]
        if isinstance(_value, Unset):
            value = UNSET
        else:
            value = database_multi_value_issue_custom_field_value_m.DatabaseMultiValueIssueCustomFieldValue.from_dict(
                _value
            )

        database_multi_value_issue_custom_field = cls(
            project_custom_field=project_custom_field,
            value=value,
            **_IssueCustomField_kwargs,
        )

        database_multi_value_issue_custom_field.additional_properties = d
        return database_multi_value_issue_custom_field

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
